==> ejc-production-impl-3.0.0-20220610.134712-133-sources.jar: com/ejianc/business/production/bean/ProductiontasktransportEntity.java <==
package com.ejianc.business.production.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 任务单运输信息
 * 
 * @author generator
 * 
 */
 @TableName("ejc_production_task_transport")
public class ProductiontasktransportEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="task_id")
    private Long taskId; // 生产任务单id
    @TableField(value="task_code")
    private String taskCode; // 生产任务单单号
    @TableField(value="shippers_id")
    private Long shippersId; // 运输商主键id
    @TableField(value="shippers_name")
    private String shippersName; // 运输商名称
    @TableField(value="shippers_vehicle_id")
    private Long shippersVehicleId; // 运输商车辆主键id
    @TableField(value="shippers_vehicle_name")
    private String shippersVehicleName; // 运输商车辆名称
    @TableField(value="shippers_vehicle_code")
    private String shippersVehicleCode; // 车辆照号
    @TableField(value="bill_state")
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="change_id")
    private Long changeId; // 变更单据id
    @TableField(value="change_state")
    private String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="transport_count")
    private BigDecimal transportCount; // 运输重量
    @TableField(value="transport_time")
    private Date transportTime; // 运输时间
    @TableField(value="transport_method")
    private String transportMethod; // 运输方式
    @TableField(value="transport_statue")
    private Integer transportStatue; // 发货状态
    @TableField(value="tare")
    private BigDecimal tare; // 皮重
    @TableField(value="sort")
    private Integer sort; // 序号
    @TableField(value="unit_id")
    private Long unitId; // 机组名称
    @TableField(value="unit_name")
    private String unitName; // 机组名称
    @TableField(value="unitdistribute_id")
    private Long unitdistributeId; // 分配机组id
    @TableField(value="customer_manage_id")
    private Long customerManageId; // 客户管理档案id
    @TableField(value="customer_manage_name")
    private String customerManageName; // 客户管理档案名称
    @TableField(value="project_id")
    private Long projectId; // 工程id
    @TableField(value="project_name")
    private String projectName; // 工程名称
    @TableField(value="worksite_id")
    private Long worksiteId; // 工地id
    @TableField(value="worksite_name")
    private String worksiteName; // 工地名称
    @TableField(value="counting_method")
    private Integer countingMethod; // 计数方法
    @TableField(value="product_id")
    private Long productId; // 产品id
    @TableField(value="product_name")
    private String productName; // 产品名称
    @TableField(value="distance")
    private BigDecimal distance; // 距离
    @TableField(value="order_name")
    private String orderName; // 定料人
    @TableField(value="order_mobile")
    private String orderMobile; // 联系电话
    @TableField(value="transport_route")
    private String transportRoute; // 行车路线
    @TableField(value="print_customer_name")
    private String printCustomerName; // 打印客户名称
    @TableField(value="print_product_name")
    private String printProductName; // 打印产品名称
    @TableField(value="print_worksite_name")
    private String printWorksiteName; // 打印工地名称
    @TableField(value="print_supply_name")
    private String printSupplyName; // 打印供应商名称



    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getTaskId() {
        return taskId;
    }

    public void setTaskId(Long taskId) {
        this.taskId = taskId;
    }
    public String getTaskCode() {
        return taskCode;
    }

    public void setTaskCode(String taskCode) {
        this.taskCode = taskCode;
    }
    public Long getShippersId() {
        return shippersId;
    }

    public void setShippersId(Long shippersId) {
        this.shippersId = shippersId;
    }
    public String getShippersName() {
        return shippersName;
    }

    public void setShippersName(String shippersName) {
        this.shippersName = shippersName;
    }
    public Long getShippersVehicleId() {
        return shippersVehicleId;
    }

    public void setShippersVehicleId(Long shippersVehicleId) {
        this.shippersVehicleId = shippersVehicleId;
    }
    public String getShippersVehicleName() {
        return shippersVehicleName;
    }

    public void setShippersVehicleName(String shippersVehicleName) {
        this.shippersVehicleName = shippersVehicleName;
    }
    public String getShippersVehicleCode() {
        return shippersVehicleCode;
    }

    public void setShippersVehicleCode(String shippersVehicleCode) {
        this.shippersVehicleCode = shippersVehicleCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public String getChangeState() {
        return changeState;
    }

    public void setChangeState(String changeState) {
        this.changeState = changeState;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public BigDecimal getTransportCount() {
        return transportCount;
    }

    public void setTransportCount(BigDecimal transportCount) {
        this.transportCount = transportCount;
    }

    public Date getTransportTime() {
        return transportTime;
    }

    public void setTransportTime(Date transportTime) {
        this.transportTime = transportTime;
    }

    public String getTransportMethod() {
        return transportMethod;
    }

    public void setTransportMethod(String transportMethod) {
        this.transportMethod = transportMethod;
    }

    public Integer getTransportStatue() {
        return transportStatue;
    }

    public void setTransportStatue(Integer transportStatue) {
        this.transportStatue = transportStatue;
    }

    public BigDecimal getTare() {
        return tare;
    }

    public void setTare(BigDecimal tare) {
        this.tare = tare;
    }

    public Integer getSort() {
        return sort;
    }

    public void setSort(Integer sort) {
        this.sort = sort;
    }

    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }

    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }

    public Long getUnitdistributeId() {
        return unitdistributeId;
    }

    public void setUnitdistributeId(Long unitdistributeId) {
        this.unitdistributeId = unitdistributeId;
    }

    public Long getCustomerManageId() {
        return customerManageId;
    }

    public void setCustomerManageId(Long customerManageId) {
        this.customerManageId = customerManageId;
    }

    public String getCustomerManageName() {
        return customerManageName;
    }

    public void setCustomerManageName(String customerManageName) {
        this.customerManageName = customerManageName;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public Long getWorksiteId() {
        return worksiteId;
    }

    public void setWorksiteId(Long worksiteId) {
        this.worksiteId = worksiteId;
    }

    public String getWorksiteName() {
        return worksiteName;
    }

    public void setWorksiteName(String worksiteName) {
        this.worksiteName = worksiteName;
    }

    public Integer getCountingMethod() {
        return countingMethod;
    }

    public void setCountingMethod(Integer countingMethod) {
        this.countingMethod = countingMethod;
    }

    public Long getProductId() {
        return productId;
    }

    public void setProductId(Long productId) {
        this.productId = productId;
    }

    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }

    public BigDecimal getDistance() {
        return distance;
    }

    public void setDistance(BigDecimal distance) {
        this.distance = distance;
    }

    public String getOrderName() {
        return orderName;
    }

    public void setOrderName(String orderName) {
        this.orderName = orderName;
    }

    public String getOrderMobile() {
        return orderMobile;
    }

    public void setOrderMobile(String orderMobile) {
        this.orderMobile = orderMobile;
    }

    public String getTransportRoute() {
        return transportRoute;
    }

    public void setTransportRoute(String transportRoute) {
        this.transportRoute = transportRoute;
    }

    public String getPrintCustomerName() {
        return printCustomerName;
    }

    public void setPrintCustomerName(String printCustomerName) {
        this.printCustomerName = printCustomerName;
    }

    public String getPrintProductName() {
        return printProductName;
    }

    public void setPrintProductName(String printProductName) {
        this.printProductName = printProductName;
    }

    public String getPrintWorksiteName() {
        return printWorksiteName;
    }

    public void setPrintWorksiteName(String printWorksiteName) {
        this.printWorksiteName = printWorksiteName;
    }

    public String getPrintSupplyName() {
        return printSupplyName;
    }

    public void setPrintSupplyName(String printSupplyName) {
        this.printSupplyName = printSupplyName;
    }
}

==> ejc-production-impl-3.0.0-20220615.135539-150-sources.jar: com/ejianc/business/production/bean/ProductiontasktransportEntity.java <==
package com.ejianc.business.production.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 任务单运输信息
 * 
 * @author generator
 * 
 */
 @TableName("ejc_production_task_transport")
public class ProductiontasktransportEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="task_id")
    private Long taskId; // 生产任务单id
    @TableField(value="task_code")
    private String taskCode; // 生产任务单单号
    @TableField(value="shippers_id")
    private Long shippersId; // 运输商主键id
    @TableField(value="shippers_name")
    private String shippersName; // 运输商名称
    @TableField(value="shippers_vehicle_id")
    private Long shippersVehicleId; // 运输商车辆主键id
    @TableField(value="shippers_vehicle_name")
    private String shippersVehicleName; // 运输商车辆名称
    @TableField(value="shippers_vehicle_code")
    private String shippersVehicleCode; // 车辆照号
    @TableField(value="bill_state")
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="change_id")
    private Long changeId; // 变更单据id
    @TableField(value="change_state")
    private String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="transport_count")
    private BigDecimal transportCount; // 运输重量
    @TableField(value="transport_time")
    private Date transportTime; // 运输时间
    @TableField(value="transport_method")
    private String transportMethod; // 运输方式
    @TableField(value="transport_statue")
    private Integer transportStatue; // 发货状态
    @TableField(value="tare")
    private BigDecimal tare; // 皮重
    @TableField(value="sort")
    private Integer sort; // 序号
    @TableField(value="unit_id")
    private Long unitId; // 机组名称
    @TableField(value="unit_name")
    private String unitName; // 机组名称
    @TableField(value="unitdistribute_id")
    private Long unitdistributeId; // 分配机组id
    @TableField(value="customer_manage_id")
    private Long customerManageId; // 客户管理档案id
    @TableField(value="customer_manage_name")
    private String customerManageName; // 客户管理档案名称
    @TableField(value="project_id")
    private Long projectId; // 工程id
    @TableField(value="project_name")
    private String projectName; // 工程名称
    @TableField(value="worksite_id")
    private Long worksiteId; // 工地id
    @TableField(value="worksite_name")
    private String worksiteName; // 工地名称
    @TableField(value="counting_method")
    private Integer countingMethod; // 计数方法
    @TableField(value="product_id")
    private Long productId; // 产品id
    @TableField(value="product_name")
    private String productName; // 产品名称
    @TableField(value="distance")
    private BigDecimal distance; // 距离
    @TableField(value="order_name")
    private String orderName; // 定料人
    @TableField(value="order_mobile")
    private String orderMobile; // 联系电话
    @TableField(value="transport_route")
    private String transportRoute; // 行车路线
    @TableField(value="print_customer_name")
    private String printCustomerName; // 打印客户名称
    @TableField(value="print_product_name")
    private String printProductName; // 打印产品名称
    @TableField(value="print_worksite_name")
    private String printWorksiteName; // 打印工地名称
    @TableField(value="print_supply_name")
    private String printSupplyName; // 打印供应商名称
    @TableField(value="is_more_project")
    private String isMoreProject; // 是否多工程
    @TableField(value="shipment_quantity")
    private BigDecimal shipmentQuantity; // 发货数量


    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getTaskId() {
        return taskId;
    }

    public void setTaskId(Long taskId) {
        this.taskId = taskId;
    }
    public String getTaskCode() {
        return taskCode;
    }

    public void setTaskCode(String taskCode) {
        this.taskCode = taskCode;
    }
    public Long getShippersId() {
        return shippersId;
    }

    public void setShippersId(Long shippersId) {
        this.shippersId = shippersId;
    }
    public String getShippersName() {
        return shippersName;
    }

    public void setShippersName(String shippersName) {
        this.shippersName = shippersName;
    }
    public Long getShippersVehicleId() {
        return shippersVehicleId;
    }

    public void setShippersVehicleId(Long shippersVehicleId) {
        this.shippersVehicleId = shippersVehicleId;
    }
    public String getShippersVehicleName() {
        return shippersVehicleName;
    }

    public void setShippersVehicleName(String shippersVehicleName) {
        this.shippersVehicleName = shippersVehicleName;
    }
    public String getShippersVehicleCode() {
        return shippersVehicleCode;
    }

    public void setShippersVehicleCode(String shippersVehicleCode) {
        this.shippersVehicleCode = shippersVehicleCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public String getChangeState() {
        return changeState;
    }

    public void setChangeState(String changeState) {
        this.changeState = changeState;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public BigDecimal getTransportCount() {
        return transportCount;
    }

    public void setTransportCount(BigDecimal transportCount) {
        this.transportCount = transportCount;
    }

    public Date getTransportTime() {
        return transportTime;
    }

    public void setTransportTime(Date transportTime) {
        this.transportTime = transportTime;
    }

    public String getTransportMethod() {
        return transportMethod;
    }

    public void setTransportMethod(String transportMethod) {
        this.transportMethod = transportMethod;
    }

    public Integer getTransportStatue() {
        return transportStatue;
    }

    public void setTransportStatue(Integer transportStatue) {
        this.transportStatue = transportStatue;
    }

    public BigDecimal getTare() {
        return tare;
    }

    public void setTare(BigDecimal tare) {
        this.tare = tare;
    }

    public Integer getSort() {
        return sort;
    }

    public void setSort(Integer sort) {
        this.sort = sort;
    }

    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }

    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }

    public Long getUnitdistributeId() {
        return unitdistributeId;
    }

    public void setUnitdistributeId(Long unitdistributeId) {
        this.unitdistributeId = unitdistributeId;
    }

    public Long getCustomerManageId() {
        return customerManageId;
    }

    public void setCustomerManageId(Long customerManageId) {
        this.customerManageId = customerManageId;
    }

    public String getCustomerManageName() {
        return customerManageName;
    }

    public void setCustomerManageName(String customerManageName) {
        this.customerManageName = customerManageName;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public Long getWorksiteId() {
        return worksiteId;
    }

    public void setWorksiteId(Long worksiteId) {
        this.worksiteId = worksiteId;
    }

    public String getWorksiteName() {
        return worksiteName;
    }

    public void setWorksiteName(String worksiteName) {
        this.worksiteName = worksiteName;
    }

    public Integer getCountingMethod() {
        return countingMethod;
    }

    public void setCountingMethod(Integer countingMethod) {
        this.countingMethod = countingMethod;
    }

    public Long getProductId() {
        return productId;
    }

    public void setProductId(Long productId) {
        this.productId = productId;
    }

    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }

    public BigDecimal getDistance() {
        return distance;
    }

    public void setDistance(BigDecimal distance) {
        this.distance = distance;
    }

    public String getOrderName() {
        return orderName;
    }

    public void setOrderName(String orderName) {
        this.orderName = orderName;
    }

    public String getOrderMobile() {
        return orderMobile;
    }

    public void setOrderMobile(String orderMobile) {
        this.orderMobile = orderMobile;
    }

    public String getTransportRoute() {
        return transportRoute;
    }

    public void setTransportRoute(String transportRoute) {
        this.transportRoute = transportRoute;
    }

    public String getPrintCustomerName() {
        return printCustomerName;
    }

    public void setPrintCustomerName(String printCustomerName) {
        this.printCustomerName = printCustomerName;
    }

    public String getPrintProductName() {
        return printProductName;
    }

    public void setPrintProductName(String printProductName) {
        this.printProductName = printProductName;
    }

    public String getPrintWorksiteName() {
        return printWorksiteName;
    }

    public void setPrintWorksiteName(String printWorksiteName) {
        this.printWorksiteName = printWorksiteName;
    }

    public String getPrintSupplyName() {
        return printSupplyName;
    }

    public void setPrintSupplyName(String printSupplyName) {
        this.printSupplyName = printSupplyName;
    }

    public String getIsMoreProject() {
        return isMoreProject;
    }

    public void setIsMoreProject(String isMoreProject) {
        this.isMoreProject = isMoreProject;
    }

    public BigDecimal getShipmentQuantity() {
        return shipmentQuantity;
    }

    public void setShipmentQuantity(BigDecimal shipmentQuantity) {
        this.shipmentQuantity = shipmentQuantity;
    }
}
